pub trait HostStreamObjectNames: Send {
// Required methods
fn read_stream_object_names(
&mut self,
self_: Resource<StreamObjectNames>,
len: u64,
) -> impl Future<Output = Result<Result<(Vec<ObjectName>, bool), Error>>> + Send;
fn skip_stream_object_names(
&mut self,
self_: Resource<StreamObjectNames>,
num: u64,
) -> impl Future<Output = Result<Result<(u64, bool), Error>>> + Send;
fn drop(
&mut self,
rep: Resource<StreamObjectNames>,
) -> impl Future<Output = Result<()>> + Send;
}Required Methods
Sourcefn read_stream_object_names(
&mut self,
self_: Resource<StreamObjectNames>,
len: u64,
) -> impl Future<Output = Result<Result<(Vec<ObjectName>, bool), Error>>> + Send
fn read_stream_object_names( &mut self, self_: Resource<StreamObjectNames>, len: u64, ) -> impl Future<Output = Result<Result<(Vec<ObjectName>, bool), Error>>> + Send
reads the next number of objects from the stream
This function returns the list of objects read, and a boolean indicating if the end of the stream was reached.
Sourcefn skip_stream_object_names(
&mut self,
self_: Resource<StreamObjectNames>,
num: u64,
) -> impl Future<Output = Result<Result<(u64, bool), Error>>> + Send
fn skip_stream_object_names( &mut self, self_: Resource<StreamObjectNames>, num: u64, ) -> impl Future<Output = Result<Result<(u64, bool), Error>>> + Send
skip the next number of objects in the stream
This function returns the number of objects skipped, and a boolean indicating if the end of the stream was reached.
fn drop( &mut self, rep: Resource<StreamObjectNames>, ) -> impl Future<Output = Result<()>> + Send
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<_T: HostStreamObjectNames + ?Sized + Send> HostStreamObjectNames for &mut _T
impl<_T: HostStreamObjectNames + ?Sized + Send> HostStreamObjectNames for &mut _T
Sourcefn read_stream_object_names(
&mut self,
self_: Resource<StreamObjectNames>,
len: u64,
) -> impl Future<Output = Result<Result<(Vec<ObjectName>, bool), Error>>> + Send
fn read_stream_object_names( &mut self, self_: Resource<StreamObjectNames>, len: u64, ) -> impl Future<Output = Result<Result<(Vec<ObjectName>, bool), Error>>> + Send
reads the next number of objects from the stream
This function returns the list of objects read, and a boolean indicating if the end of the stream was reached.
Sourcefn skip_stream_object_names(
&mut self,
self_: Resource<StreamObjectNames>,
num: u64,
) -> impl Future<Output = Result<Result<(u64, bool), Error>>> + Send
fn skip_stream_object_names( &mut self, self_: Resource<StreamObjectNames>, num: u64, ) -> impl Future<Output = Result<Result<(u64, bool), Error>>> + Send
skip the next number of objects in the stream
This function returns the number of objects skipped, and a boolean indicating if the end of the stream was reached.